@@ -113,8 +113,10 @@ pango_attr_type_get_name (PangoAttrType type)
  * @attr: a #PangoAttribute
  * @klass: a #PangoAttributeClass
  *
- * Initializes @attr's klass to @klass, it's start_index to zero,
- * and end_index to %G_MAXUINT such that the attribute applies
+ * Initializes @attr's klass to @klass,
+ * it's start_index to %PANGO_ATTR_INDEX_FROM_TEXT_BEGINNING
+ * and end_index to %PANGO_ATTR_INDEX_TO_TEXT_END
+ * such that the attribute applies
  * to the entire text by default.
  *
  * Since: 1.20
@@ -127,8 +129,8 @@ pango_attribute_init (PangoAttribute       *attr,
   g_return_if_fail (klass != NULL);
 
   attr->klass = klass;
-  attr->start_index = 0;
-  attr->end_index = G_MAXUINT;
+  attr->start_index = PANGO_ATTR_INDEX_FROM_TEXT_BEGINNING;
+  attr->end_index   = PANGO_ATTR_INDEX_TO_TEXT_END;
 }
 
 /**
@@ -1131,7 +1133,7 @@ pango_attr_list_ref (PangoAttrList *list)
   if (list == NULL)
     return NULL;
 
-  g_atomic_int_inc (&list->ref_count);
+  g_atomic_int_inc ((int *) &list->ref_count);
 
   return list;
 }
@@ -1154,7 +1156,7 @@ pango_attr_list_unref (PangoAttrList *list)
 
   g_return_if_fail (list->ref_count > 0);
 
-  if (g_atomic_int_dec_and_test (&list->ref_count))
+  if (g_atomic_int_dec_and_test ((int *) &list->ref_count))
     {
       tmp_list = list->attributes;
       while (tmp_list)
@@ -1791,7 +1793,8 @@ pango_attr_iterator_get (PangoAttrIterator *iterator,
  *        <literal>pango_font_description_set_family (desc, pango_font_description_get_family (desc))</literal>.
  * @language: if non-%NULL, location to store language tag for item, or %NULL
  *            if none is found.
- * @extra_attrs: if non-%NULL, location in which to store a list of non-font
+ * @extra_attrs: (element type Pango.Attribute): (transfer full): if non-%NULL,
+ *           location in which to store a list of non-font
  *           attributes at the the current position; only the highest priority
  *           value of each attribute will be added to this list. In order
  *           to free this value, you must call pango_attribute_destroy() on
@@ -1828,7 +1831,7 @@ pango_attr_iterator_get_font (PangoAttrIterator     *iterator,
       PangoAttribute *attr = tmp_list1->data;
       tmp_list1 = tmp_list1->next;
 
-      switch (attr->klass->type)
+      switch ((int) attr->klass->type)
 	{
 	case PANGO_ATTR_FONT_DESC:
 	  {
@@ -2011,7 +2014,8 @@ pango_attr_list_filter (PangoAttrList       *list,
  * Gets a list of all attributes at the current position of the
  * iterator.
  *
- * Return value: a list of all attributes for the current range.
+ * Return value: (element-type Pango.Attribute): (transfer full): a list of
+ *   all attributes for the current range.
  *   To free this value, call pango_attribute_destroy() on
  *   each value and g_slist_free() on the list.
  *
