@@ -19,7 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include "pango-attributes.h"
 #include "pango-item.h"
 #include "pango-impl-utils.h"
@@ -42,18 +42,24 @@ pango_item_new (void)
 
 /**
  * pango_item_copy:
- * @item: a #PangoItem
+ * @item: a #PangoItem, may be %NULL
  *
  * Copy an existing #PangoItem structure.
  *
  * Return value: the newly allocated #PangoItem, which should
- *               be freed with pango_item_free().
+ *               be freed with pango_item_free(), or %NULL if
+ *               @item was NULL.
  **/
 PangoItem *
 pango_item_copy (PangoItem *item)
 {
   GSList *extra_attrs, *tmp_list;
-  PangoItem *result = g_slice_new (PangoItem);
+  PangoItem *result;
+
+  if (item == NULL)
+    return NULL;
+  
+  result = g_slice_new (PangoItem);
 
   result->offset = item->offset;
   result->length = item->length;
@@ -78,13 +84,16 @@ pango_item_copy (PangoItem *item)
 
 /**
  * pango_item_free:
- * @item: a #PangoItem
+ * @item: a #PangoItem, may be %NULL
  *
  * Free a #PangoItem and all associated memory.
  **/
 void
 pango_item_free (PangoItem *item)
 {
+  if (item == NULL)
+    return;
+
   if (item->analysis.extra_attrs)
     {
       g_slist_foreach (item->analysis.extra_attrs, (GFunc)pango_attribute_destroy, NULL);
@@ -102,7 +111,7 @@ pango_item_get_type (void)
 {
   static GType our_type = 0;
 
-  if (our_type == 0)
+  if (G_UNLIKELY (our_type == 0))
     our_type = g_boxed_type_register_static (I_("PangoItem"),
 					     (GBoxedCopyFunc) pango_item_copy,
 					     (GBoxedFreeFunc) pango_item_free);
@@ -137,7 +146,6 @@ pango_item_split (PangoItem  *orig,
   PangoItem *new_item;
 
   g_return_val_if_fail (orig != NULL, NULL);
-  g_return_val_if_fail (orig->length > 0, NULL);
   g_return_val_if_fail (split_index > 0, NULL);
   g_return_val_if_fail (split_index < orig->length, NULL);
   g_return_val_if_fail (split_offset > 0, NULL);
